@@ -10,13 +10,10 @@ This is a convenience object, used as a proxy for an object inside a pairtree st
 As such, it shouldn't be instanciated directly.
 """
 
-import os, sys, shutil
+import os
+from pairtree.storage_exceptions import *
+from pairtree import myutils
 
-import codecs
-
-import string
-
-from storage_exceptions import *
 
 class PairtreeStorageObject(object):
     """
@@ -107,7 +104,7 @@ class PairtreeStorageObject(object):
     >>> print bar.get_bytestream('foo.txt')
     can be any sequence of bytes
     """
-    def __init__(self, id, fs_store_client):
+    def __init__(self, id, fs_store_client, location=None):
         """
         @param id: Identifier for pairtree object
         @type id: identifier
@@ -117,6 +114,7 @@ class PairtreeStorageObject(object):
         self.fs = fs_store_client
         self.id = id
         self.uri = "%s%s" % (self.fs.uri_base, id)
+        self.location = location
 
     def add_bytestream(self, filename, bytestream, path=None, buffer_size=None):
         """
@@ -208,6 +206,18 @@ class PairtreeStorageObject(object):
         path, filename = os.path.split(filepath)
         return self.get_bytestream(filename, streamable, path, appendable)
 
+    def add_directory(self, from_file_location):
+        """
+        Adds a directory tree from a given location.
+                
+        @param from_file_location: Path to read the directory tree from
+        @type from_file_location: Directory path
+        """
+        if os.path.exists(from_file_location):
+            myutils.copytree(from_file_location, self.location)
+        else:
+            raise FileNotFoundException
+
     def add_file(self, from_file_location, path=None, new_filename=None, buffer_size=None):
         """
         Adds a file from a given location. Currently, the copy is due via python buffering
@@ -222,7 +232,7 @@ class PairtreeStorageObject(object):
         @type from_file_location: Directory path
         @param path: (Optional) subdirectory within object to store file in
         @type path: Directory path
-        @param new_filename: Name of the file to write to
+        @param new_filename: (Optional) Name of the file to write to
         @type new_filename: filename
         @param buffer_size: (Optional) Used for streaming filelike objects - defines the size of the buffer
         to read in each cycle.
